#
# spec file for package Ipopt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 3
%define shlib libipopt%{sover}
Name:           Ipopt
Version:        3.14.13
Release:        1.1
Summary:        A software package for large-scale nonlinear optimization methods
License:        EPL-2.0
Group:          Development/Libraries/C and C++
URL:            https://projects.coin-or.org/Ipopt
Source0:        https://github.com/coin-or/Ipopt/archive/releases/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  blas-devel
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  graphviz
BuildRequires:  graphviz-gd
BuildRequires:  java-devel
BuildRequires:  javapackages-tools
BuildRequires:  lapack-devel
BuildRequires:  metis-devel
BuildRequires:  mumps-devel
BuildRequires:  pkgconfig
BuildRequires:  strip-nondeterminism
BuildRequires:  texlive-bibtex-bin
BuildRequires:  texlive-dvips-bin
BuildRequires:  texlive-latex-bin
ExcludeArch:    i586 s390 ppc armv7l

%description
Ipopt (Interior Point OPTimizer, pronounced eye-pea-Opt) is a software
package for large-scale nonlinear optimization.

%package -n %{shlib}
Summary:        A software package for large-scale nonlinear optimization methods
Group:          System/Libraries
# Previously the shlib was incorrectly named, hence the Obsoletes
Obsoletes:      libipopt0 < %{version}

%description -n %{shlib}
Ipopt (Interior Point OPTimizer, pronounced eye-pea-Opt) is a software
package for large-scale nonlinear optimization.

%package devel
Summary:        Development and header files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
Requires:       mumps-devel
Provides:       ipopt-devel = %{version}

%description devel
This package contains the development and header files for %{name}.

%package java
Summary:        Java bindings for %{name}
Group:          Development/Libraries/C and C++
BuildArch:      noarch

%description java
This package provides the java bindings for %{name} in a jar file.

%prep
%setup -q -n %{name}-releases-%{version}

%build
%configure --docdir=%{_docdir}/%{name} \
           --with-mumps-cflags="-I%{_includedir}/mumps" \
           --with-mumps-lflags="-L%{_libdir} -ldmumps_seq"

%make_build all
# create docs in a separate step for reproducible build results (boo#1102408)
%make_build doc

%install
%make_install
strip-nondeterminism %{buildroot}%{_javadir}/org.coinor.ipopt.jar

# REMOVE FILES TO BE PACKAGED USING %%doc
for f in AUTHORS README.md LICENSE ChangeLog.md;
do
  rm %{buildroot}%{_docdir}/%{name}/${f}
done

find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}%{_datadir}/coin/doc

%check
%make_build test

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/*.so.%{sover}*

%files devel
%doc README.md AUTHORS ChangeLog.md
%doc doc/html
%license LICENSE
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/ipopt.pc

%files java
%license LICENSE
%{_javadir}/org.coinor.ipopt.jar

%changelog
* Wed Nov 22 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.13:
  * Reduced priority for making Spral the default value for option
    linear_solver [gh#coin-or/Ipopt#677].
  * Adapted to change of integer types in Spral interface. Minimal
    required Spral version is now v2023.03.29.
  * Fixed that return code from TNLP::eval_jac_g() was ignored at
    first call [gh#coin-or/Ipopt#697].
  * Print additional messages when reallocation of MA27 working
    space failed [gh#coin-or/Ipopt#671].
  * Added option file_append to specify whether to append to
    output_file instead of truncating it.
  * Added default argument file_append to
    Journalist::AddFileJournal(), added default argument fappend
    to FileJournal::Open(), and added default argument file_append
    to IpoptApplication::OpenOutputFile() [gh#coin-or/Ipopt#720].
* Mon Apr 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.12:
  * Fix that a source file was installed and install more header
    files [gh#coin-or/Ipopt#641, gh#coin-or/Ipopt#642].
  * Fixed crash of GetIpoptCurrentIterate() and
    GetIpoptCurrentViolations() in C interface when called before
    or after IpoptSolve() [gh#coin-or/Ipopt#644,
    gh#coin-or/Ipopt#645].
  * Updated HSL_MA97 header file to the one from HSL MA97 2.8.0
    [gh#coin-or/Ipopt#646].
  * Fixed crash when trying to solve problem without variables and
    constraints [gh#coin-or/Ipopt#648].
  * Added optional argument to AlgorithmBuilder constructor to
    provide name of custom solver [gh#coin-or/Ipopt#618].
  * Changed handling of dual solution for square problems.
  * Updated HSL_MC86 header file to the one from HSL MC68 3.3.3
    [gh#coin-or/Ipopt#653].
- Make java package noarch (rpmlint recommends).
* Sun Oct 23 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.10:
  * Added option grad_f_constant to specify that objective
    function is linear. If set, the gradient of the objective will
    be requested by Ipopt only once [gh#coin-or/Ipopt#597].
  * Added OrigIpoptNLP::orig_d_L() and OrigIpoptNLP::orig_d_U() to
    get original constraint sides.
  * TNLP::get_curr_violations() now returns the constraint
    violation and complementarity with respect to the original
    (non-relaxed) constraint sides [gh#coin-or/Ipopt#603].
* Wed Aug 10 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.9:
  * Fixed mapping of meta data for variable bounds, e.g., variable
    names, from TNLP to Ipopts internal NLP [gh#coin-or/Ipopt#590]
* Thu Jul 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.8:
  * Added options ma27_print_level, ma57_print_level, and
    mumps_print_level to enable output from these linear solvers.
* Mon Jul  4 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.7:
  * Fixed that ComputeSensitivityMatrix() of sIpopt assumed that
    there are no more than two parameters [gh#coin-or/Ipopt#578].
  * For completeness_approximation to enable approximation of
    gradient of objective function by finite differences. Do not
    use. [gh#coin-or/Ipopt#573].
  * Added function IPSETPROBLEMSCALING to Fortran interface to set
    problem scaling [gh#coin-or/Ipopt#577].
* Fri May  6 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.6:
  * Fixed mapping of meta data for inequalities, e.g., constraint
    names, from TNLP to Ipopts internal NLP
    [gh#coin-or/Ipopt#570].
  * Fixed that MC68 ordering time was not accounted in symbolic
    factorization time of HSL MA86 [gh#coin-or/Ipopt#571].
  * Include more header files in IpIpoptCalculatedQuantities.hpp
    for setups where forward declarations are not sufficient
    [gh#coin-or/Ipopt#572].
* Sun Feb 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Drop the incorrect Provides: libipopt0 on libipopt3.
- Make so version inaccuracies harder to miss by making file list
  more explicit on the versioning.
* Sat Feb 19 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add Obsoletes/Provides: libipopt0 for libipopt3 to take care of
  shlib versioning error in previously packaged iterations.
* Mon Feb 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.5:
  * Fixed that only primal variable values where passed to
    finalize_solution() when a timelimit was reached
    [gh#coin-or/Ipopt#552].
- Bump so version in keeping with upstream.
* Thu Oct 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.4:
  * Skip build of Java interface if either java or jar is not
    found [gh#coin-or/Ipopt#510]. Only give warning if javac and
    jar are found, but no java or javadoc.
  * Fixed that --with-lapack-lflags was ignored if --with-lapack
    was not specified explicitly [gh#coin-or/Ipopt#512,
    gh#coin-or/Ipopt#515].
* Wed Sep 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.3:
  * Fixed timing for iterate initialization if initialization
    fails due to an evaluation error.
  * Fixed possible integer overflow when reserving space for
    indices of Jacobian belonging to fixed variables (introduced
    with 3.14.0) and reduced memory usage for indices of Jacobian
    belonging to fixed variables.
* Wed Jul 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.2:
  * Added OptionsList::UnsetValue() to remove an option setting.
  * Added missing translation of some Ipopt status codes into AMPL
    solve result codes.
  * If using the MPI-parallel version of MUMPS: Moved calls to
    MPI_Init()/MPI_Finalize() in MUMPS interface into global
    constructor/destructor of Ipopt library (if building with
    GCC/clang). Use configure flag --disable-mpiinit to disable.
    [gh#coin-or/Ipopt#500].
* Wed Jun 30 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.1:
  * Added OptionsList::SetBoolValue() and
    OptionsList::SetBoolValueIfUnset() [gh#coin-or/Ipopt#492].
  * Skip check for and link against libdl if linear solver loader
    is disabled.
  * Fixed missing initialization of
    BacktrackingLineSearch::in_watchdog_.
  * Fixed a problem with the current solution not being reset when
    initialization of a NLP fails in reoptimization.
  * Fixed that C++11 capability was not correctly identified with
    MS/Intel compilers.
* Wed Jun 16 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.14.0
  * Long list of changes, consult ChangeLog.md installed in
    %%{_docdir}/Ipopt-devel or see here:
    https://github.com/coin-or/Ipopt/blob/releases/3.14.0/ChangeLog.md.
- Package ChangeLog.md as part of doc files.
* Tue May 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build for architectures where mumps does not exist
  (i586 s390 ppc armv7l).
* Thu Feb 25 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.13.4:
  * Fixed a linking issue for ipopt_sens [gh#coin-or/Ipopt#418].
  * Fixed Makefile for Java example regarding location of .jar
    file.
  * Fixed build of R interface if using -fvisibility=hidden.
* Wed Oct 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.13.3:
  * Members of class AmplTNLP are now protected instead of
    private.
  * Updated Eclipse Public License from 1.0 to 2.0.
  * Added example recursive_nlp that uses Ipopt to solves an
    optimization problem for the evaluation of the objective
    function.
  * Fixed dangling pointer problems with Journalist used for
    debugging (--with-ipopt-verbosity > 0) when more than one
    IpoptApplication is used [gh#coin-or/Ipopt#393].
  * Fixed build problem when using HSL library that does not
    include MA27, MA57, or MC19 [gh#coin-or/Ipopt#395].
  * Fixed build of linear-solver loader on Windows
    [gh#coin-or/Ipopt#408].
- Update License tag to EPL-2.0 in keeping with upstream.
* Wed Jul 15 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- BuildRequire graphviz-gd for dot -Tpng to work
- Normalize jar timestamps with strip-nondeterminism
- Create docs in a separate step for reproducible build results
  (boo#1102408).
* Thu Apr 30 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.13.2:
  * The C-preprocessor defines COIN_IPOPT_CHECKLEVEL,
    COIN_IPOPT_VERBOSITY, and FORTRAN_INTEGER_TYPE, which are
    defined by IpoptConfig.h, have been renamed to
    IPOPT_CHECKLEVEL, IPOPT_VERBOSITY, and
    IPOPT_FORTRAN_INTEGER_TYPE, respectively. They are still
    available under their previous name, but these will be removed
    in Ipopt 3.14.
  * Changed dependencies as used by coinbrew to use new versions
    (2.1) of ThirdParty/HSL and ThirdParty/MUMPS and dropped
    ThirdParty/Metis.
  * The new versions of the HSL and MUMPS build scripts now look
    for a Metis library in the system and should work with both
    Metis 4 and Metis 5.
  * Changed location where Java interface jar gets installed from
    $libdir to $datadir/java/.
  * Minor fixes to buildsystem.
- No longer needed to manually create %%{_libdir} before `make
  install` or to move jar file to %%{_javadir}; issue
  gh#coin-or/Ipopt#374 has been fixed.
* Thu Apr 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.13.1:
  * Added asserts that check whether sparsity pattern of Jacobian
    and Hessian as returned by TNLP are within range w.r.t. number
    of variables and constraints. [gh#coin-or/Ipopt#350]
  * TNLPAdapter::ResortBnds now initializes complete output arrays
    with 0.0 before filling in values for non-fixed variables. Use
    new argument clearorig to turn this off [gh#coin-or/Ipopt#352]
  * Bring back configure variables ADD_{C,CXX,F}FLAGS
  * Added configure option --enable-relocatable to make prefix in
    pkg-config files relative to pcfiledir (assuming that --libdir
    hasn't been set)
  * Bring back configall_system.h for build without config header
  * Minor fixes to buildsystem
- Fix License tag: EPL-1.0, not GPL-2.0.
- BuildRequires: texlive-bibtex-bin, graphviz now required to
  build API documentation.
- Adapt configure options to updated build system.
- Package built html documentation.
- Work around build failure when building java bindings: create
  %%{_libdir} before running `make install` [gh#coin-or/Ipopt#374].
- Split out a separate -java subpackage for the java bindings;
  introduces BuildRequires: java-devel, javapackages-tools.
- Run make test as past of %%check.
- Run spec-cleaner for minor specfile cleanups.
* Wed Apr 24 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.12.13
  * fixed Pardiso settings when using Pardiso from Pardiso project
    website (by Olaf Schenk): the new settings should provide much
    better performance; the default for option pardiso_order changed
    from five to metis
  * changed distinction of MKL and Basel Pardiso in configure: to
    use MKL Pardiso, only specify MKL for Blas; to use Basel Pardiso,
    use --with-pardiso
- For changes from previously packaged version through version
  3.12.12 see the changelog file:
  %%{_docdir}/Ipopt-devel/ChangeLog
- Drop Ipopt-pkg-config-path-fix.patch: fixed upstream.
- Build doxygen documentation; requires doxygen, texlive-latex-bin
  and dvips
- Use %%%%license to package license file.
- Cleanups using spec-cleaner.
* Fri Nov 28 2014 kkhere.geo@gmail.com
- update to version 3.11.9
  * 2014-08-16 releases/3.11.9
  - fix compilation issue of Java interface on systems where Index
    and jint have different size [r2498, #241]
  - work around failing check for random number generator with gcc
    4.8.3 [r2495, r2496]
  - readded IpTaggedObject.cpp to list of sources to compile in
    MSVS v8-ifort project file [r2492]
  - work around missing support for thread-local storage with gcc < 4.5
    on MacOS X [r2491, #243]
  - fix call to MKL Pardiso init function [r2489]
  - speed up Triplet to CSR converter [r2487, #234]
  - fixed a bug in equilibration scaling where average values were
    computed incorrectly (by V. Zverovich) [r2483]
  * 2014-04-08 releases/3.11.8
  - fixed a bug, introduced with Ipopt 3.11.0, where the tag in the
    Ipopt's caching mechanism was not unique over time, which lead
    to failures of Ipopt that were difficult to debug or recognize
    (e.g., Ipopt may have stopped with an restoration failure for
    instances that solved fine with Ipopt 3.10) [r2472, r2473]
    I'm very thankful to Gabriel Hackebeil and Kurt Majewski for
    their debugging effort on this issue.
  - building Mumps with pthreads is now disabled by default [#229]
  - fixed setting of LD on Windows (now set to link only iff using
    MS/Intel compilers) [#230]
  - fixed download link for Gnumex [r2471]
  - for some messages about too-few-degrees-of-freedom and restoration
    failure, the message level changed from error to strong-warning
    [r2460, r2469]
  - revised calls to MPI_Init and MPI_Finalize in Mumps interface [r2467]
    (MPI_Init is now called only if function MPI_Initialized is available
    and MPI has not been initialized already; MPI_Finalize is only called
    if Ipopt also called MPI_Init; ...)
* Thu Jan 16 2014 kkhere.geo@gmail.com
- fixed installation with pkg-config
  https://projects.coin-or.org/BuildTools/ticket/104
- update to version 3.11.7
  * 2013-12-18 releases/3.11.7
  - adapted PARDISO parameters when using MKL PARDISO to be close
    to using Basel PARDISO
  - added options pardiso_max_iterative_refinement_steps and
    pardiso_order; the former defaults to 1 in case of MKL PARDISO,
    which may help on instances that otherwise fail due to numerical issues
  - removed duplicate code in IpQualityFunctionMuOracle.cpp [#225, r2445]
  - fixed bug in triplet to csr converter [#226, r2446]
  - minor changes in buildsystem
  * 2013-11-16 releases/3.11.6
  - updates to Matlab Interface build system (by T. Kelman)
  - fix to updates of R Interface [r2416, #223]
  - fixed SHAREDLIBEXT in v8-ifort's config.h [r2426, #224]
  - minor fixes to the buildsystem
  * 2013-10-26 releases/3.11.5
  - added method IpoptApplication::RethrowNonIpoptException() to enable
    rethrowing of non-ipopt and non-bad_alloc exceptions catched in
    the *Optimize() and Initialization() methods; default is still to
    return with NonIpopt_Exception_Thrown status
  - minor fixes to the buildsystem [#215, #222]
  * 2013-09-12 releases/3.11.4
  - hopefully fixed non-working linear solver loader in DLLs build with
    MSVS/v8-ifort project files [r2365]
  - allow MC19 to be loaded via linear solver loader (by J. Currie) [r2366]
  - fixed new point flag when running dependendency detector [r2368]
  - experimental: adapt Pardiso interface to work with MKL Pardiso
    (by J. Currie, T. Kelman) [r2369, #216]:
  - in a few tests it has been found that Pardiso from Intel MKL nowadays
    seems to work fine with Ipopt
  - to use Intel MKL with Ipopt 3.11, one has to specify the MKL libs via
  - -with-pardiso and add -DHAVE_PARDISO_MKL -DHAVE_PARDISO_PARALLEL
    to the compiler flags
  - note that this is still an experimental feature (and thus not enabled
    by default)
  - updated Ipopt/R interface to version 0.8.4 [r2373]
  - additional variables have been included in the object returned from ipoptr:
    z_L : final values for the lower bound multipliers
    z_U : final values for the upper bound multipliers
    constraints : final values for the constraints
    lambda : final values for the Lagrange multipliers
  - removed ipoptr_environment as argument in ipoptr (see also r2372)
  - fixed bug in penalty term for centrality in quality function (not used by
    default) [#219, r2374]
  - minor bugfixes in AMPL interface, debug print statements, and compound matrix
    (by G. Hackebeil) [#218, r2371, r2377, r2378, r2379]
  - download scripts for ASL, Blas, and Lapack now first try to download tarball
    copies from the COIN-OR server
  * 2013-08-08 releases/3.11.3
  - get.* scripts for ThirdParty/{ASL,Blas,Lapack} now work around broken
    ftp access to www.netlib.org.
  * 2013-07-01 releases/3.11.2
  - changed default for option option_file_name to ipopt.opt; specifying an
    empty string for this option now disables reading of an option file [r2339]
  - missing initial values are now set to 0.0, projected onto variable bounds,
    in AMPL interface [r2340, #205]
  - fixed missing variable initialization in MA97 interface [r2341, #206]
  * 2013-06-14 releases/3.11.1
  - the setup for the v8-ifort MSVS project changed to use dynamic runtime
    DLLs instead of static linking, which caused crashes in debug mode
    (by M. Roelofs) [r2301]
  - fixed memory leaks in Java Interface (by javier) [#200, r2312]
  - updates and fixes to MA77 and MA87 interfaces, adding support of
    HSL 2013 codes (by J. Hogg);
    HSL 2012 still supported when compiled with Ipopt, but the linear solver
    loader to dynamically load a HSL library at runtime now assumes HSL 2013
  - added option ma97_solve_blas3 (by J. Hogg) [r2329]
  - changed default for option ma27_meminc_factor from 10.0 to 2.0 [r2330]
  - fixed bug in ipopt_auxdata of MATLAB Interface related to iterfunc [r2325]
  * 2013-05-07 releases/3.11.0
  - update and extension of Ipopt documentation
  - updated build of doxygen documentation to comply with other COIN-OR projects
  - localized global variables in TaggedObject and RegisteredOption,
    so that Ipopt should now be threadsafe as long as Ipopt objects
    (esp. SmartPtr's) are not shared between threads and a threadsafe
    linear solver is used (e.g., MA27) [#167]
  - no more need for whitespace character at end of options file
  - added options print_frequency_iter and print_frequency_time to regulate
    which iteration summary lines should be printed [#161]
  - function evaluation timings are now available in OrigIpoptNLP [#86]
  - some fixes to uncommon issues with the Ipopt SmartPtr [#162]
  - new build system for Harwell codes (ThirdParty/HSL), which requires
    the coin-hsl archives from http://www.hsl.rl.ac.uk/ipopt/;
    previously downloaded HSL sources can still be used by placing them
    into ThirdParty/HSLold, but this option may be removed in a future
    Ipopt version
  - new interfaces for Harwell codes HSL_MA77, HSL_MA86, and HSL_MA97;
    see http://www.hsl.rl.ac.uk/ipopt/ about help on when to use which solver;
    especially MA57 and HSL_MA97 should be considered as replacement for MA27;
    however, MA27 is still the default for now
  - changed default of ma57_automatic_scaling to no (faster in general,
    but for higher reliability, you may want to set this option to yes)
  - major improvements for building the MATLAB interface (see documentation)
  - MATLAB interface now returns number of function evaluations, too
  - the MA57 interface can now be used with the MA57 library that comes with
    MATLAB (configure option --enable-matlab-ma57; cannot use Metis)
  - auxdata is now handled by a wrapper function ipopt_auxdata.m instead
    of internally within the mex code (replace Matlab call to ipopt with
    ipopt_auxdata if using auxiliary data in any callbacks) [r2282]
  - exposed more intermediate Ipopt information to iterfunc callback [r2283]
  - fixes to JIpopt buildsystem (now may work on windows and uses libtool)
  - JIpopt now reads options file ipopt.opt by default, if present
  - removed predefined KEY_ strings in JIpopt
  - renamed API functions that retrieve solution values in JIpopt
  - simplified installation of R interface
  * 2013-05-05 releases/3.10.4
  - fixed sign of dual values in AMPL solution again (with help of Gabe)
    [r2169, r2170, r2184, #183]
  - fixed bugs with reoptimizing a TNLP with all variables fixed [r2172, r2173, #179]
  - fixed more issues with sparse data structures and non-double numbers
    in Matlab interface (by T. Kelman) [r2191]
  - added missing final int for Ipopt return code Maximum_CpuTime_Exceeded
    in Java interface [r2216]
  - fixed bug when trying to warmstart Ipopt in Java interface [r2253]
  - fixed wrong use of SmartPtr's in Java interface [r2255, r2263]
  - fixed bug in returning final solution in Java interface [r2258]
  - included patch in ThirdParty/Mumps to work around bugs in Mumps
    matrix ordering routines AMF and QAMD (now give preference to AMD and METIS)
  * 2012-11-19 releases/3.10.3
  - minor fixes in MA86 interface (by Jonathan Hogg) [r2069, r2086]
  - fix in IpTripletToCSRConverter for CSR forms with
    extra entries (by Jonathan Hogg) [r2087]
  - workaround problems with MacOSX-Lion's blas library
    (by Frederic Hetch) [r2102, #181]
  - the C interface now catches also Ipopt exceptions thrown
    within the OptimizeTNLP call and returns Ipopt::Unrecoverable_Exception
    as status [r2094, #144]
  - fixed segmentation fault in adaptive barrier parameter update rule
    when using the mehrotra option on unconstrained problems [r2114, #114]
  - fixed segmentation fault in case no iterate is available in case of
    catastrophic failure in restoration phase [r2115]
  - fixed default for mumps_dep_tol to work with current Mumps versions [r2116]
  - fixed sign of dual values in AMPL solution [r2123, #183]
  - fixed issue with sparse gradients in Matlab interface
    (by T. Kelman) [r2133, #187]
  - sIPOPT (by H. Pirnay):
  - starting values in C++ version of parametric example now
    match AMPL version [r2098]
  - numerical values in parametric example now match publication [r2099]
  - added options n_sens_steps and sens_boundcheck as AMPL options [r2099]
  - any non-zero suffix value is now accepted for sens_init_constr [r2100]
  - fix typo in AMPL interface (by Weifeng Chen) [r2110]
  - fix bug when compiling without AMPL interface [r2113]
  - build system:
  - updated instruction on using nowadays HSL sources (by T. Kelman)
  - fixed issue with libdir being <prefix>/lib64
  - other minor fixes
* Wed Sep 19 2012 kkhere.geo@gmail.com
- Build with mumps (sequential version) as linear solver
* Sat Aug 25 2012 scorot@free.fr
- first package
